Struct amazon_sp_finances::models::seller_review_enrollment_payment_event::SellerReviewEnrollmentPaymentEvent
source · [−]pub struct SellerReviewEnrollmentPaymentEvent {
pub posted_date: Option<String>,
pub enrollment_id: Option<String>,
pub parent_asin: Option<String>,
pub fee_component: Option<Box<FeeComponent>>,
pub charge_component: Option<Box<ChargeComponent>>,
pub total_amount: Option<Box<Currency>>,
}Expand description
SellerReviewEnrollmentPaymentEvent : A fee payment event for the Early Reviewer Program.
Fields
posted_date: Option<String>enrollment_id: Option<String>An enrollment identifier.
parent_asin: Option<String>The Amazon Standard Identification Number (ASIN) of the item that was enrolled in the Early Reviewer Program.
fee_component: Option<Box<FeeComponent>>charge_component: Option<Box<ChargeComponent>>total_amount: Option<Box<Currency>>Implementations
sourceimpl SellerReviewEnrollmentPaymentEvent
impl SellerReviewEnrollmentPaymentEvent
sourcepub fn new() -> SellerReviewEnrollmentPaymentEvent
pub fn new() -> SellerReviewEnrollmentPaymentEvent
A fee payment event for the Early Reviewer Program.